// $Id: RayTracePhoton.cxx,v 1.2 2006/02/22 01:47:29 hoshina Exp $
//*************************************************************************
//* --------------------
//* RayTracePhoton
//* --------------------
//* (Description)
//*	Particle class which represents an optical photon.
//* (Update Record)
//*	2003/12/22  K.Hoshina	Original version.
//*     2004/8/23   S.Yoshida   Adding the wavelength/ 
//*                             the cathode coordinate field
//*************************************************************************
#include <TMath.h>

#include "raytrace/RayTracePhoton.h"

ClassImp(RayTracePhoton)

const TString  RayTracePhoton::kParticleName = "RayTracePhoton";
UInt_t         RayTracePhoton::fID           = 0;

//_________________________________________________________________________
RayTracePhoton::RayTracePhoton() 
               //: RMOOpticalPhoton(), RMOVAttBuffer()
               //: RMOVAttBuffer(), RMOOpticalPhoton()
               : RMOOpticalPhoton()
{
//
// Only TBuffer uses the default constructor.
//
   fUniqueName = kParticleName;
   fUniqueName += fID;
   fID++;
}

//_________________________________________________________________________
RayTracePhoton::RayTracePhoton(const TVector3 &pos,
                               const TVector3 &dir) 
               //: RMOOpticalPhoton(pos, dir), RMOVAttBuffer()
               //: RMOVAttBuffer(), RMOOpticalPhoton(pos, dir)
               : RMOOpticalPhoton(pos, dir)
{
   fUniqueName = kParticleName;
   fUniqueName += fID;
   fID++;
}

//_________________________________________________________________________
void RayTracePhoton::DumpInfo(const Option_t* opt) 
{

   TVector3 pos = GetPosition();
   TVector3 dir = GetDirection();

   cerr << "*---------------------------------------------------------*" << endl;
   cerr << "* DumpInfo of " << fUniqueName << endl;
   cerr << "* pos                         dir                        dist" << endl;
   cerr << "* (" << pos.X() << "," << pos.Y() << "," << pos.Z() << ") ("
        <<  dir.X() << "," << dir.Y() << "," << dir.Z() << ") " << pos.Mag() << endl;
   cerr << "* ++++ trace history ++++" << endl;
   cerr << "* step_id  pos               photon_dir             scat_costheta" << endl;

   for (Int_t i = 0; i<(Int_t)fHistory.GetEntries(); i++) {
      RMOOpticalPhoton *ph = dynamic_cast<RMOOpticalPhoton*>(fHistory[i]);
      if (!ph) continue;
      pos = ph->GetPosition();
      dir = ph->GetDirection();
      cerr << "* " << i << " ("  << pos.X() << "," << pos.Y() << "," << pos.Z() 
           << ")  ("  << dir.X() << "," << dir.Y() << "," << dir.Z() << ")  " 
           << ph->GetCosTheta()<< endl;
   }
}
   
