#ifndef __RayTrace__H__
#define __RayTrace__H__

//*************************************************************************
//* ---------------------
//* RayTrace Class
//* ---------------------
//* (Description)
//*     Toy Monte-Carlo for photon propagation in Ice 
//* (Requires)
//* (Provides)
//* (Update Record)
//*	2004/04/15  K.Hoshina	Original version.
//*************************************************************************

#include "TVector3.h"
#include "TH1D.h"
#include "TF1.h"
#include "TLegend.h"
#include "TLatex.h"
#include "TFile.h"
#include "TRandom.h"
#include <iomanip>
#include <vector>

#include "romeo/kern/RMOVModule.h"
#include "raytrace/PhotonBuf.h"
#include "raytrace/RayTraceUtil.h"

using namespace std;

class RayTrace : public RMOVModule, public RayTraceUtil {

public:

  RayTrace(const Char_t *name = "RayTrace", 
           const Char_t *title = "RayTrace module");
  virtual ~RayTrace();

  virtual void Configure();
  virtual void Process()  ;
  virtual void Finish()   ;
  virtual void Draw();

  virtual const TObject &GetBuffer() const { return fShellBuffers; }

  inline void  SetNshells(Int_t n)       { fNshells    = n; }
  inline void  SetRadiusStep(Double_t x) { fRadiusStep = x; }
  inline void  SetOffsetShellRadius(Double_t x) { fOffsetShellRadius = x; }

private:

  static Int_t    FindIntersection(const TVector3 &oldpos,
                                   const TVector3 &olddir,
                                   const TVector3 &newdir,
                                   Double_t curshell,
                                   TVector3 intersection[]);

private:

  Double_t  fOffsetShellRadius; // offset radius of shells
  Int_t     fNshells;         // Number of shells 
  Double_t  fRadiusStep;      // distance between a shell to the next shell [m]

  TFile    *fOutFile;         // TFile to store the results
  TString   fOutFileName;     // name of the TFile
  PhotonBuf fShellBuffers;    // array of buffers to keep arrival photons at i-th shell 

  TH1D     *fHdNdL;           // Histogram  of dN/dLambda
  vector<TF1*> fWLSpect_r;    // Function of Wave Length  

  ClassDef(RayTrace, 1)       // Ray trace Monte-Carlo program

};

#endif

