// $Id: RMOVModule.h,v 1.1.1.1 2005/06/23 11:43:50 hoshina Exp $
#ifndef __RMOVModule__H__
#define __RMOVModule__H__

//*************************************************************************
//* ---------------------
//* RMOVModule Class
//* ---------------------
//* (Description)
//*     Abstract module class for modules.
//* (Requires)
//* (Provides)
//*	RMOVModule              : base class for modules
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************


#include <TTask.h>
#include <iostream>
#include <fstream>

#include "romeo/kern/RMOEnumDef.h"
#include "romeo/kern/RMOAttVerbose.h"

using namespace std;

class RMOVModule : public TTask, public RMOAttVerbose {

public:

  RMOVModule():TTask(), RMOAttVerbose(){}
  RMOVModule(const Char_t *name, const Char_t *title);

  virtual ~RMOVModule();

  virtual void    Configure() = 0;
  virtual void    Process()   = 0;
  virtual void    Finish()    = 0;
  virtual void    Draw()      = 0;
  virtual void    ClearBuffer();
  virtual void    ClearEvent();

  virtual const  TObject &GetBuffer() const = 0;
  virtual const  TObject &GetImputBuffer();     
 
  virtual void           Add(RMOVModule* module);
  virtual void           Add(TTask* module);
  static  EState         CurrentState()                 { return fgState;  }
  static  void           ChangeState(EState st=kALIVE)  { fgState = st;    }
  virtual void           Exec(Option_t *opt);
  virtual RMOVModule    *GetMother() const              { return fMother;  }
  static  RMOVModule    *GetLastTask()                  { return fgLastTask; }
  virtual Bool_t         HasExecutedProcess()           { return fHasExecutedProcess;}
  virtual void           SetMother(RMOVModule *m)       { fMother = m;     }

private:

  static EState      fgState;           // state of simulated particle 
  static RMOVModule *fgLastTask;        // state of simulated particle 
  RMOVModule        *fMother;           // pointer to its mother RMOVModule;
  Bool_t             fHasExecutedProcess; // boolean flag of executed of Process

  ClassDef(RMOVModule, 1)            // abstract base class for modules

};

//=====================================
// inline function
//=====================================


#endif

