//
//
// analysis.C
//
// 

#include <iomanip.h>

TFile foutp;


int Raytrace(Int_t nevts=1, TString fname="raytrace")
//int raytrace(Int_t nevts, char* fname)
{

  gROOT->Reset();
  //gDebug = 1;

  gSystem->Load("libPhysics.so");
  gSystem->Load("../lib/libRMOKernel.so");
  gSystem->Load("../lib/libraytrace.so");
    
  gStyle->SetOptStat(0);
  gStyle->SetPalette(1);
  gStyle->SetCanvasColor(33);
  gStyle->SetFrameFillColor(18);

  // set random seed...

  ifstream in("random_seed.txt", ios::in);
  UInt_t seed;
  TString lastfname;
  while (!in.eof()) {
     in >> lastfname >> seed;
  }

  cerr << "last filename = " << lastfname << " : seed = " << seed << endl;
  gRandom->SetSeed(seed);

  in.close();
  in.clear(); 

  // create modules ...

  IceRayTrace *raytrace = new IceRayTrace();  
  raytrace->SetOutFileName(TString(fname));

  // set shell parameters

  raytrace->SetOffsetShellRadius(100.); // [m]
  raytrace->SetNshells(11);
  raytrace->SetRadiusStep(5.);          // [m]

  // debug mode: do you want to store stepping history?

  //raytrace->SetStoreHistory(kTRUE);    // store stepping history: large filesize
  raytrace->SetStoreHistory(kFALSE);    // don't store history

  // setting verbose level...

  raytrace->SetVerboseLevel(0);
  
  // configure...

  raytrace->ExecuteTask("Configure");

  // process...

  Int_t evt = 0;
  for (Int_t i=0; i<nevts; i++) {
     raytrace->ExecuteTask("Process");
     evt ++;
     if (evt%10000 == 0) {
        cerr << evt << " event finished!" << endl;
     }
  }

  // finish...

  raytrace->Draw();
  raytrace->ExecuteTask("Finish");

  ofstream out("random_seed.txt", ios::app);
  // Avoid to end with return, otherwise 
  // while-loop excutes an extera loop just for the last return
  out << endl;
  out << fname << " " << gRandom->GetSeed() ;
  out.close();
  out.clear();
}



